@@ -2,11 +2,12 @@ from six import python_2_unicode_compatible
 
 from .base import Ref, QuickbooksManagedObject, QuickbooksTransactionEntity, \
     LinkedTxnMixin
-from .detailline import DetailLine, AccountBasedExpenseLine, ItemBasedExpenseLine
+from .detailline import DetailLine, AccountBasedExpenseLine, ItemBasedExpenseLine, TDSLine
+from ..mixins import DeleteMixin
 
 
 @python_2_unicode_compatible
-class VendorCredit(QuickbooksManagedObject, QuickbooksTransactionEntity, LinkedTxnMixin):
+class VendorCredit(DeleteMixin, QuickbooksManagedObject, QuickbooksTransactionEntity, LinkedTxnMixin):
     """
     QBO definition: The Vendor Credit entity is an accounts payable transaction that represents a refund or credit
     of payment for goods or services. It is a credit that a vendor owes you for various reasons such as overpaid
@@ -26,7 +27,7 @@ class VendorCredit(QuickbooksManagedObject, QuickbooksTransactionEntity, LinkedT
     detail_dict = {
         "AccountBasedExpenseLineDetail": AccountBasedExpenseLine,
         "ItemBasedExpenseLineDetail": ItemBasedExpenseLine,
-
+        "TDSLineDetail": TDSLine,
     }
 
     qbo_object_name = "VendorCredit"
