@@ -1,27 +1,12 @@
-import os
-import unittest
 from datetime import datetime
 
-from quickbooks.auth import Oauth1SessionManager
-from quickbooks.client import QuickBooks
 from quickbooks.objects.taxservice import TaxService, TaxRateDetails
+from tests.integration.test_base import QuickbooksTestCase
 
 
-class TaxServiceTest(unittest.TestCase):
+class TaxServiceTest(QuickbooksTestCase):
     def setUp(self):
-        self.session_manager = Oauth1SessionManager(
-            sandbox=True,
-            consumer_key=os.environ.get('CONSUMER_KEY'),
-            consumer_secret=os.environ.get('CONSUMER_SECRET'),
-            access_token=os.environ.get('ACCESS_TOKEN'),
-            access_token_secret=os.environ.get('ACCESS_TOKEN_SECRET'),
-        )
-
-        self.qb_client = QuickBooks(
-            session_manager=self.session_manager,
-            sandbox=True,
-            company_id=os.environ.get('COMPANY_ID')
-        )
+        super(TaxServiceTest, self).setUp()
 
         self.name = "TaxCode {0}".format(datetime.now().strftime('%d%H%M'))
 
