@@ -1,5 +1,6 @@
 import unittest
 
+from quickbooks import QuickBooks
 from quickbooks.objects.invoice import Invoice, DeliveryInfo
 
 
@@ -31,6 +32,24 @@ class InvoiceTests(unittest.TestCase):
         invoice.EmailStatus = "NotSent"
         self.assertFalse(invoice.email_sent)
 
+    def test_valid_object_name(self):
+        obj = Invoice()
+        client = QuickBooks()
+        result = client.isvalid_object_name(obj.qbo_object_name)
+
+        self.assertTrue(result)
+
+    def test_to_ref(self):
+        invoice = Invoice()
+        invoice.DocNumber = 1
+        invoice.Id = 2
+
+        ref = invoice.to_ref()
+        self.assertIsInstance(ref, Ref)
+        self.assertEquals(ref.type, "Invoice")
+        self.assertEquals(ref.name, 1)  # should be DocNumber
+        self.assertEquals(ref.value, 2)  # should be Id
+
 
 class DeliveryInfoTests(unittest.TestCase):
     def test_init(self):
